#version 330 core

in vec2 uv;  // Use the same name for the varying input
out vec4 outColor;

uniform sampler2D scene;

// Simplex noise function
vec3 permute(vec3 x) {
    return mod((34.0 * x + 1.0) * x, 289.0);
}

float simplexNoise(vec2 v) {
    const vec4 C = vec4(0.211324865405187, 0.366025403784439, 
                        -0.577350269189626, 0.024390243902439);
    vec2 i  = floor(v + dot(v, C.yy) );
    vec2 x0 = v -   i + dot(i, C.xx);

    vec2 i1;
    i1 = (x0.x > x0.y) ? vec2(1.0, 0.0) : vec2(0.0, 1.0);
    vec4 x12 = x0.xyxy + C.xxzz;
    x12.xy -= i1;

    i = mod(i, 289.0);
    vec3 p = permute( permute( i.y + vec3(0.0, i1.y, 1.0 ))
                    + i.x + vec3(0.0, i1.x, 1.0 ));

    vec3 m = max(0.5 - vec3(dot(x0, x0), dot(x12.xy, x12.xy), 
                            dot(x12.zw, x12.zw)), 0.0);
    m = m * m;
    m = m * m;

    vec3 x = 2.0 * fract(p * C.www) - 1.0;
    vec3 h = abs(x) - 0.5;
    vec3 ox = floor(x + 0.5);
    vec3 a0 = x - ox;

    m *= 1.79284291400159 - 0.85373472095314 * 
         (a0 * a0 + h * h);

    vec3 g;
    g.x  = a0.x  * x0.x  + h.x  * x0.y;
    g.yz = a0.yz * x12.xz + h.yz * x12.yw;
    return 130.0 * dot(m, g);
}

void main () {
    // Calculate distance from any edge (top, bottom, left, right)
    float distanceTop = 1.0 - uv.y;
    float distanceBottom = uv.y;
    float distanceLeft = uv.x;
    float distanceRight = 1.0 - uv.x;

    // Find the minimum distance to any edge
    float distance = min(min(distanceTop, distanceBottom), min(distanceLeft, distanceRight));

    // Define light and dark brown colors
    vec3 lightBrown = vec3(0.5, 0.3, 0.1);
    vec3 darkBrown = vec3(0.4, 0.2, 0.1);

    // Sample the original color from the scene texture
    vec4 originalColor = texture(scene, uv);

    // Add noise to the distance to create a splotchy edge
    float noiseValue = simplexNoise(uv * 10.0); // Adjust scale as needed
    float splotchyDistance = 1.0 - 0.05 - distance + noiseValue * 0.1; // Adjust noise influence as needed

    // Calculate tint strength based on splotchy distance
    float tintStrength = smoothstep(0.8, 1.0, splotchyDistance); // Adjust threshold for a desired effect

    // Interpolate between light and dark brown based on noise value
    vec3 brownTint = mix(darkBrown, lightBrown, noiseValue * 0.5 + 0.5);

    // Mix the original color with the brown tint
    vec3 tintedColor = mix(originalColor.rgb, brownTint, tintStrength);

    // Set the output color
    outColor = vec4(tintedColor, originalColor.a);
}
